#[derive(RemoveLexerAttributes)]
{
// Attributes available to this derive:
#[skip]
#[frag]
#[set_mode]
#[mode]
#[modes]
}
No-op derive macro that declares the helper attributes used by the primary lexer macro.
Its a little hacky, I know, but its simpler than manually removing all of these attributes in the main macro.